# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserTwoStepVerificationGetPasswordDetail.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserTwoStepVerificationGetPasswordDetail.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n.UserTwoStepVerificationGetPasswordDetail.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"K\n(UserTwoStepVerificationGetPasswordDetail\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xd8\x01\n0UserTwoStepVerificationGetPasswordDetailResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x14\n\x0cquestion_one\x18\x02 \x01(\t\x12\x14\n\x0cquestion_two\x18\x03 \x01(\t\x12\x0c\n\x04hint\x18\x04 \x01(\t\x12$\n\x1chas_confirmed_recovery_email\x18\x05 \x01(\x08\x12!\n\x19unconfirmed_email_pattern\x18\x06 \x01(\tB?\n\x0enet.iGap.protoB-ProtoUserTwoStepVerificationGetPasswordDetailb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERTWOSTEPVERIFICATIONGETPASSWORDDETAIL = _descriptor.Descriptor(
  name='UserTwoStepVerificationGetPasswordDetail',
  full_name='proto.UserTwoStepVerificationGetPasswordDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserTwoStepVerificationGetPasswordDetail.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=163,
)


_USERTWOSTEPVERIFICATIONGETPASSWORDDETAILRESPONSE = _descriptor.Descriptor(
  name='UserTwoStepVerificationGetPasswordDetailResponse',
  full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='question_one', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.question_one', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='question_two', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.question_two', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hint', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.hint', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_confirmed_recovery_email', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.has_confirmed_recovery_email', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unconfirmed_email_pattern', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.unconfirmed_email_pattern', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=382,
)

_USERTWOSTEPVERIFICATIONGETPASSWORDDETAIL.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERTWOSTEPVERIFICATIONGETPASSWORDDETAILRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['UserTwoStepVerificationGetPasswordDetail'] = _USERTWOSTEPVERIFICATIONGETPASSWORDDETAIL
DESCRIPTOR.message_types_by_name['UserTwoStepVerificationGetPasswordDetailResponse'] = _USERTWOSTEPVERIFICATIONGETPASSWORDDETAILRESPONSE

UserTwoStepVerificationGetPasswordDetail = _reflection.GeneratedProtocolMessageType('UserTwoStepVerificationGetPasswordDetail', (_message.Message,), dict(
  DESCRIPTOR = _USERTWOSTEPVERIFICATIONGETPASSWORDDETAIL,
  __module__ = 'UserTwoStepVerificationGetPasswordDetail_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserTwoStepVerificationGetPasswordDetail)
  ))
_sym_db.RegisterMessage(UserTwoStepVerificationGetPasswordDetail)

UserTwoStepVerificationGetPasswordDetailResponse = _reflection.GeneratedProtocolMessageType('UserTwoStepVerificationGetPasswordDetailResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERTWOSTEPVERIFICATIONGETPASSWORDDETAILRESPONSE,
  __module__ = 'UserTwoStepVerificationGetPasswordDetail_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserTwoStepVerificationGetPasswordDetailResponse)
  ))
_sym_db.RegisterMessage(UserTwoStepVerificationGetPasswordDetailResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB-ProtoUserTwoStepVerificationGetPasswordDetail'))
# @@protoc_insertion_point(module_scope)
