# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InfoTime.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='InfoTime.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x0eInfoTime.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"+\n\x08InfoTime\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"H\n\x10InfoTimeResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x11\n\ttimestamp\x18\x02 \x01(\rB\x1f\n\x0enet.iGap.protoB\rProtoInfoTimeb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_INFOTIME = _descriptor.Descriptor(
  name='InfoTime',
  full_name='proto.InfoTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.InfoTime.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=99,
)


_INFOTIMERESPONSE = _descriptor.Descriptor(
  name='InfoTimeResponse',
  full_name='proto.InfoTimeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.InfoTimeResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='proto.InfoTimeResponse.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=173,
)

_INFOTIME.fields_by_name['request'].message_type = Request__pb2._REQUEST
_INFOTIMERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['InfoTime'] = _INFOTIME
DESCRIPTOR.message_types_by_name['InfoTimeResponse'] = _INFOTIMERESPONSE

InfoTime = _reflection.GeneratedProtocolMessageType('InfoTime', (_message.Message,), dict(
  DESCRIPTOR = _INFOTIME,
  __module__ = 'InfoTime_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoTime)
  ))
_sym_db.RegisterMessage(InfoTime)

InfoTimeResponse = _reflection.GeneratedProtocolMessageType('InfoTimeResponse', (_message.Message,), dict(
  DESCRIPTOR = _INFOTIMERESPONSE,
  __module__ = 'InfoTime_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoTimeResponse)
  ))
_sym_db.RegisterMessage(InfoTimeResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\rProtoInfoTime'))
# @@protoc_insertion_point(module_scope)
