# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InfoWallpaper.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='InfoWallpaper.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x13InfoWallpaper.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xdf\x01\n\rInfoWallpaper\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12%\n\x03\x66it\x18\x02 \x01(\x0e\x32\x18.proto.InfoWallpaper.Fit\x12\'\n\x04type\x18\x03 \x01(\x0e\x32\x19.proto.InfoWallpaper.Type\")\n\x03\x46it\x12\t\n\x05PHONE\x10\x00\x12\n\n\x06TABLET\x10\x01\x12\x0b\n\x07\x44\x45SKTOP\x10\x02\"2\n\x04Type\x12\x13\n\x0f\x43HAT_BACKGROUND\x10\x00\x12\x15\n\x11PROFILE_WALLPAPER\x10\x01\"_\n\x15InfoWallpaperResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12#\n\twallpaper\x18\x02 \x03(\x0b\x32\x10.proto.WallpaperB$\n\x0enet.iGap.protoB\x12ProtoInfoWallpaperb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_INFOWALLPAPER_FIT = _descriptor.EnumDescriptor(
  name='Fit',
  full_name='proto.InfoWallpaper.Fit',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PHONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TABLET', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESKTOP', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=206,
  serialized_end=247,
)
_sym_db.RegisterEnumDescriptor(_INFOWALLPAPER_FIT)

_INFOWALLPAPER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.InfoWallpaper.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHAT_BACKGROUND', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROFILE_WALLPAPER', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=249,
  serialized_end=299,
)
_sym_db.RegisterEnumDescriptor(_INFOWALLPAPER_TYPE)


_INFOWALLPAPER = _descriptor.Descriptor(
  name='InfoWallpaper',
  full_name='proto.InfoWallpaper',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.InfoWallpaper.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fit', full_name='proto.InfoWallpaper.fit', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.InfoWallpaper.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INFOWALLPAPER_FIT,
    _INFOWALLPAPER_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=299,
)


_INFOWALLPAPERRESPONSE = _descriptor.Descriptor(
  name='InfoWallpaperResponse',
  full_name='proto.InfoWallpaperResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.InfoWallpaperResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wallpaper', full_name='proto.InfoWallpaperResponse.wallpaper', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=396,
)

_INFOWALLPAPER.fields_by_name['request'].message_type = Request__pb2._REQUEST
_INFOWALLPAPER.fields_by_name['fit'].enum_type = _INFOWALLPAPER_FIT
_INFOWALLPAPER.fields_by_name['type'].enum_type = _INFOWALLPAPER_TYPE
_INFOWALLPAPER_FIT.containing_type = _INFOWALLPAPER
_INFOWALLPAPER_TYPE.containing_type = _INFOWALLPAPER
_INFOWALLPAPERRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_INFOWALLPAPERRESPONSE.fields_by_name['wallpaper'].message_type = Global__pb2._WALLPAPER
DESCRIPTOR.message_types_by_name['InfoWallpaper'] = _INFOWALLPAPER
DESCRIPTOR.message_types_by_name['InfoWallpaperResponse'] = _INFOWALLPAPERRESPONSE

InfoWallpaper = _reflection.GeneratedProtocolMessageType('InfoWallpaper', (_message.Message,), dict(
  DESCRIPTOR = _INFOWALLPAPER,
  __module__ = 'InfoWallpaper_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoWallpaper)
  ))
_sym_db.RegisterMessage(InfoWallpaper)

InfoWallpaperResponse = _reflection.GeneratedProtocolMessageType('InfoWallpaperResponse', (_message.Message,), dict(
  DESCRIPTOR = _INFOWALLPAPERRESPONSE,
  __module__ = 'InfoWallpaper_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoWallpaperResponse)
  ))
_sym_db.RegisterMessage(InfoWallpaperResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\022ProtoInfoWallpaper'))
# @@protoc_insertion_point(module_scope)
