# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChannelGetMemberList.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2
from ighap_bot.proto import ChannelAddAdmin_pb2 as ChannelAddAdmin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ChannelGetMemberList.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1a\x43hannelGetMemberList.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\x1a\x15\x43hannelAddAdmin.proto\"\xe9\x01\n\x14\x43hannelGetMemberList\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12;\n\x0b\x66ilter_role\x18\x03 \x01(\x0e\x32&.proto.ChannelGetMemberList.FilterRole\x12%\n\npagination\x18\x04 \x01(\x0b\x32\x11.proto.Pagination\";\n\nFilterRole\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06MEMBER\x10\x01\x12\r\n\tMODERATOR\x10\x02\x12\t\n\x05\x41\x44MIN\x10\x03\"\xf7\x01\n\x1c\x43hannelGetMemberListResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12:\n\x06member\x18\x02 \x03(\x0b\x32*.proto.ChannelGetMemberListResponse.Member\x1ax\n\x06Member\x12\x0e\n\x06userId\x18\x01 \x01(\x04\x12%\n\x04role\x18\x02 \x01(\x0e\x32\x17.proto.ChannelRoom.Role\x12\x37\n\x0b\x61\x64minRights\x18\x03 \x01(\x0b\x32\".proto.ChannelAddAdmin.AdminRightsB+\n\x0enet.iGap.protoB\x19ProtoChannelGetMemberListb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,ChannelAddAdmin__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CHANNELGETMEMBERLIST_FILTERROLE = _descriptor.EnumDescriptor(
  name='FilterRole',
  full_name='proto.ChannelGetMemberList.FilterRole',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEMBER', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODERATOR', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADMIN', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=280,
  serialized_end=339,
)
_sym_db.RegisterEnumDescriptor(_CHANNELGETMEMBERLIST_FILTERROLE)


_CHANNELGETMEMBERLIST = _descriptor.Descriptor(
  name='ChannelGetMemberList',
  full_name='proto.ChannelGetMemberList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ChannelGetMemberList.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChannelGetMemberList.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_role', full_name='proto.ChannelGetMemberList.filter_role', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='proto.ChannelGetMemberList.pagination', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANNELGETMEMBERLIST_FILTERROLE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=339,
)


_CHANNELGETMEMBERLISTRESPONSE_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='proto.ChannelGetMemberListResponse.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='proto.ChannelGetMemberListResponse.Member.userId', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='proto.ChannelGetMemberListResponse.Member.role', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='adminRights', full_name='proto.ChannelGetMemberListResponse.Member.adminRights', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=589,
)

_CHANNELGETMEMBERLISTRESPONSE = _descriptor.Descriptor(
  name='ChannelGetMemberListResponse',
  full_name='proto.ChannelGetMemberListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ChannelGetMemberListResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member', full_name='proto.ChannelGetMemberListResponse.member', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CHANNELGETMEMBERLISTRESPONSE_MEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=589,
)

_CHANNELGETMEMBERLIST.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CHANNELGETMEMBERLIST.fields_by_name['filter_role'].enum_type = _CHANNELGETMEMBERLIST_FILTERROLE
_CHANNELGETMEMBERLIST.fields_by_name['pagination'].message_type = Global__pb2._PAGINATION
_CHANNELGETMEMBERLIST_FILTERROLE.containing_type = _CHANNELGETMEMBERLIST
_CHANNELGETMEMBERLISTRESPONSE_MEMBER.fields_by_name['role'].enum_type = Global__pb2._CHANNELROOM_ROLE
_CHANNELGETMEMBERLISTRESPONSE_MEMBER.fields_by_name['adminRights'].message_type = ChannelAddAdmin__pb2._CHANNELADDADMIN_ADMINRIGHTS
_CHANNELGETMEMBERLISTRESPONSE_MEMBER.containing_type = _CHANNELGETMEMBERLISTRESPONSE
_CHANNELGETMEMBERLISTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CHANNELGETMEMBERLISTRESPONSE.fields_by_name['member'].message_type = _CHANNELGETMEMBERLISTRESPONSE_MEMBER
DESCRIPTOR.message_types_by_name['ChannelGetMemberList'] = _CHANNELGETMEMBERLIST
DESCRIPTOR.message_types_by_name['ChannelGetMemberListResponse'] = _CHANNELGETMEMBERLISTRESPONSE

ChannelGetMemberList = _reflection.GeneratedProtocolMessageType('ChannelGetMemberList', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELGETMEMBERLIST,
  __module__ = 'ChannelGetMemberList_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelGetMemberList)
  ))
_sym_db.RegisterMessage(ChannelGetMemberList)

ChannelGetMemberListResponse = _reflection.GeneratedProtocolMessageType('ChannelGetMemberListResponse', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _CHANNELGETMEMBERLISTRESPONSE_MEMBER,
    __module__ = 'ChannelGetMemberList_pb2'
    # @@protoc_insertion_point(class_scope:proto.ChannelGetMemberListResponse.Member)
    ))
  ,
  DESCRIPTOR = _CHANNELGETMEMBERLISTRESPONSE,
  __module__ = 'ChannelGetMemberList_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelGetMemberListResponse)
  ))
_sym_db.RegisterMessage(ChannelGetMemberListResponse)
_sym_db.RegisterMessage(ChannelGetMemberListResponse.Member)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\031ProtoChannelGetMemberList'))
# @@protoc_insertion_point(module_scope)
