# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MplGetCardToCardToken.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='MplGetCardToCardToken.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1bMplGetCardToCardToken.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"L\n\x15MplGetCardToCardToken\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x12\n\nto_user_id\x18\x02 \x01(\x04\"\x87\x01\n\x1dMplGetCardToCardTokenResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\t\x12\x13\n\x0b\x65xpire_time\x18\x04 \x01(\r\x12\x0f\n\x07message\x18\x05 \x01(\tB,\n\x0enet.iGap.protoB\x1aProtoMplGetCardToCardTokenb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_MPLGETCARDTOCARDTOKEN = _descriptor.Descriptor(
  name='MplGetCardToCardToken',
  full_name='proto.MplGetCardToCardToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.MplGetCardToCardToken.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_user_id', full_name='proto.MplGetCardToCardToken.to_user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=145,
)


_MPLGETCARDTOCARDTOKENRESPONSE = _descriptor.Descriptor(
  name='MplGetCardToCardTokenResponse',
  full_name='proto.MplGetCardToCardTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.MplGetCardToCardTokenResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.MplGetCardToCardTokenResponse.status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.MplGetCardToCardTokenResponse.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_time', full_name='proto.MplGetCardToCardTokenResponse.expire_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.MplGetCardToCardTokenResponse.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=283,
)

_MPLGETCARDTOCARDTOKEN.fields_by_name['request'].message_type = Request__pb2._REQUEST
_MPLGETCARDTOCARDTOKENRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['MplGetCardToCardToken'] = _MPLGETCARDTOCARDTOKEN
DESCRIPTOR.message_types_by_name['MplGetCardToCardTokenResponse'] = _MPLGETCARDTOCARDTOKENRESPONSE

MplGetCardToCardToken = _reflection.GeneratedProtocolMessageType('MplGetCardToCardToken', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETCARDTOCARDTOKEN,
  __module__ = 'MplGetCardToCardToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetCardToCardToken)
  ))
_sym_db.RegisterMessage(MplGetCardToCardToken)

MplGetCardToCardTokenResponse = _reflection.GeneratedProtocolMessageType('MplGetCardToCardTokenResponse', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETCARDTOCARDTOKENRESPONSE,
  __module__ = 'MplGetCardToCardToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetCardToCardTokenResponse)
  ))
_sym_db.RegisterMessage(MplGetCardToCardTokenResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\032ProtoMplGetCardToCardToken'))
# @@protoc_insertion_point(module_scope)
