# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GeoGetNearbyCoordinate.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GeoGetNearbyCoordinate.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1cGeoGetNearbyCoordinate.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"S\n\x16GeoGetNearbyCoordinate\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lon\x18\x03 \x01(\x01\"\xcb\x01\n\x1eGeoGetNearbyCoordinateResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12<\n\x06result\x18\x02 \x03(\x0b\x32,.proto.GeoGetNearbyCoordinateResponse.Result\x1aH\n\x06Result\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\x12\x13\n\x0bhas_comment\x18\x02 \x01(\x08\x12\x0b\n\x03lat\x18\x03 \x01(\x01\x12\x0b\n\x03lon\x18\x04 \x01(\x01\x42-\n\x0enet.iGap.protoB\x1bProtoGeoGetNearbyCoordinateb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GEOGETNEARBYCOORDINATE = _descriptor.Descriptor(
  name='GeoGetNearbyCoordinate',
  full_name='proto.GeoGetNearbyCoordinate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GeoGetNearbyCoordinate.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lat', full_name='proto.GeoGetNearbyCoordinate.lat', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lon', full_name='proto.GeoGetNearbyCoordinate.lon', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=153,
)


_GEOGETNEARBYCOORDINATERESPONSE_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='proto.GeoGetNearbyCoordinateResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.GeoGetNearbyCoordinateResponse.Result.user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_comment', full_name='proto.GeoGetNearbyCoordinateResponse.Result.has_comment', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lat', full_name='proto.GeoGetNearbyCoordinateResponse.Result.lat', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lon', full_name='proto.GeoGetNearbyCoordinateResponse.Result.lon', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=359,
)

_GEOGETNEARBYCOORDINATERESPONSE = _descriptor.Descriptor(
  name='GeoGetNearbyCoordinateResponse',
  full_name='proto.GeoGetNearbyCoordinateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GeoGetNearbyCoordinateResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='proto.GeoGetNearbyCoordinateResponse.result', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GEOGETNEARBYCOORDINATERESPONSE_RESULT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=359,
)

_GEOGETNEARBYCOORDINATE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GEOGETNEARBYCOORDINATERESPONSE_RESULT.containing_type = _GEOGETNEARBYCOORDINATERESPONSE
_GEOGETNEARBYCOORDINATERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GEOGETNEARBYCOORDINATERESPONSE.fields_by_name['result'].message_type = _GEOGETNEARBYCOORDINATERESPONSE_RESULT
DESCRIPTOR.message_types_by_name['GeoGetNearbyCoordinate'] = _GEOGETNEARBYCOORDINATE
DESCRIPTOR.message_types_by_name['GeoGetNearbyCoordinateResponse'] = _GEOGETNEARBYCOORDINATERESPONSE

GeoGetNearbyCoordinate = _reflection.GeneratedProtocolMessageType('GeoGetNearbyCoordinate', (_message.Message,), dict(
  DESCRIPTOR = _GEOGETNEARBYCOORDINATE,
  __module__ = 'GeoGetNearbyCoordinate_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetNearbyCoordinate)
  ))
_sym_db.RegisterMessage(GeoGetNearbyCoordinate)

GeoGetNearbyCoordinateResponse = _reflection.GeneratedProtocolMessageType('GeoGetNearbyCoordinateResponse', (_message.Message,), dict(

  Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), dict(
    DESCRIPTOR = _GEOGETNEARBYCOORDINATERESPONSE_RESULT,
    __module__ = 'GeoGetNearbyCoordinate_pb2'
    # @@protoc_insertion_point(class_scope:proto.GeoGetNearbyCoordinateResponse.Result)
    ))
  ,
  DESCRIPTOR = _GEOGETNEARBYCOORDINATERESPONSE,
  __module__ = 'GeoGetNearbyCoordinate_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetNearbyCoordinateResponse)
  ))
_sym_db.RegisterMessage(GeoGetNearbyCoordinateResponse)
_sym_db.RegisterMessage(GeoGetNearbyCoordinateResponse.Result)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\033ProtoGeoGetNearbyCoordinate'))
# @@protoc_insertion_point(module_scope)
