# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientCountRoomHistory.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientCountRoomHistory.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1c\x43lientCountRoomHistory.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"J\n\x16\x43lientCountRoomHistory\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\"\xb6\x01\n\x1e\x43lientCountRoomHistoryResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05media\x18\x02 \x01(\r\x12\r\n\x05image\x18\x03 \x01(\r\x12\r\n\x05video\x18\x04 \x01(\r\x12\r\n\x05\x61udio\x18\x05 \x01(\r\x12\r\n\x05voice\x18\x06 \x01(\r\x12\x0b\n\x03gif\x18\x07 \x01(\r\x12\x0c\n\x04\x66ile\x18\x08 \x01(\r\x12\x0b\n\x03url\x18\t \x01(\rB-\n\x0enet.iGap.protoB\x1bProtoClientCountRoomHistoryb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CLIENTCOUNTROOMHISTORY = _descriptor.Descriptor(
  name='ClientCountRoomHistory',
  full_name='proto.ClientCountRoomHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientCountRoomHistory.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ClientCountRoomHistory.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=144,
)


_CLIENTCOUNTROOMHISTORYRESPONSE = _descriptor.Descriptor(
  name='ClientCountRoomHistoryResponse',
  full_name='proto.ClientCountRoomHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientCountRoomHistoryResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='media', full_name='proto.ClientCountRoomHistoryResponse.media', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image', full_name='proto.ClientCountRoomHistoryResponse.image', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='video', full_name='proto.ClientCountRoomHistoryResponse.video', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audio', full_name='proto.ClientCountRoomHistoryResponse.audio', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='voice', full_name='proto.ClientCountRoomHistoryResponse.voice', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gif', full_name='proto.ClientCountRoomHistoryResponse.gif', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file', full_name='proto.ClientCountRoomHistoryResponse.file', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='proto.ClientCountRoomHistoryResponse.url', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=329,
)

_CLIENTCOUNTROOMHISTORY.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTCOUNTROOMHISTORYRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['ClientCountRoomHistory'] = _CLIENTCOUNTROOMHISTORY
DESCRIPTOR.message_types_by_name['ClientCountRoomHistoryResponse'] = _CLIENTCOUNTROOMHISTORYRESPONSE

ClientCountRoomHistory = _reflection.GeneratedProtocolMessageType('ClientCountRoomHistory', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTCOUNTROOMHISTORY,
  __module__ = 'ClientCountRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientCountRoomHistory)
  ))
_sym_db.RegisterMessage(ClientCountRoomHistory)

ClientCountRoomHistoryResponse = _reflection.GeneratedProtocolMessageType('ClientCountRoomHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTCOUNTROOMHISTORYRESPONSE,
  __module__ = 'ClientCountRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientCountRoomHistoryResponse)
  ))
_sym_db.RegisterMessage(ClientCountRoomHistoryResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\033ProtoClientCountRoomHistory'))
# @@protoc_insertion_point(module_scope)
