# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserRegister.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserRegister.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x12UserRegister.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\x81\x02\n\x0cUserRegister\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x14\n\x0cphone_number\x18\x02 \x01(\x04\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12?\n\x11preference_method\x18\x04 \x01(\x0e\x32$.proto.UserRegister.PreferenceMethod\x12\x0e\n\x06\x61pp_id\x18\x05 \x01(\r\"S\n\x10PreferenceMethod\x12\x14\n\x10VERIFY_CODE_AUTO\x10\x00\x12\x13\n\x0fVERIFY_CODE_SMS\x10\x01\x12\x14\n\x10VERIFY_CODE_CALL\x10\x02\"\x93\x03\n\x14UserRegisterResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x12\x13\n\x0b\x61uthor_hash\x18\x04 \x01(\t\x12\x32\n\x06method\x18\x05 \x01(\x0e\x32\".proto.UserRegisterResponse.Method\x12\x14\n\x0cresend_delay\x18\x06 \x01(\r\x12\x12\n\nsms_number\x18\x07 \x03(\x04\x12\x19\n\x11verify_code_regex\x18\x08 \x01(\t\x12\x1f\n\x17verify_code_digit_count\x18\t \x01(\r\x12\x1d\n\x15\x63\x61ll_method_supported\x18\n \x01(\x08\"g\n\x06Method\x12\x13\n\x0fVERIFY_CODE_SMS\x10\x00\x12\x16\n\x12VERIFY_CODE_SOCKET\x10\x01\x12\x1a\n\x16VERIFY_CODE_SMS_SOCKET\x10\x02\x12\x14\n\x10VERIFY_CODE_CALL\x10\x03\x42#\n\x0enet.iGap.protoB\x11ProtoUserRegisterb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_USERREGISTER_PREFERENCEMETHOD = _descriptor.EnumDescriptor(
  name='PreferenceMethod',
  full_name='proto.UserRegister.PreferenceMethod',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_AUTO', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_SMS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_CALL', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=235,
  serialized_end=318,
)
_sym_db.RegisterEnumDescriptor(_USERREGISTER_PREFERENCEMETHOD)

_USERREGISTERRESPONSE_METHOD = _descriptor.EnumDescriptor(
  name='Method',
  full_name='proto.UserRegisterResponse.Method',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_SMS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_SOCKET', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_SMS_SOCKET', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_CALL', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=621,
  serialized_end=724,
)
_sym_db.RegisterEnumDescriptor(_USERREGISTERRESPONSE_METHOD)


_USERREGISTER = _descriptor.Descriptor(
  name='UserRegister',
  full_name='proto.UserRegister',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserRegister.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='proto.UserRegister.phone_number', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='proto.UserRegister.country_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='preference_method', full_name='proto.UserRegister.preference_method', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='proto.UserRegister.app_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERREGISTER_PREFERENCEMETHOD,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=318,
)


_USERREGISTERRESPONSE = _descriptor.Descriptor(
  name='UserRegisterResponse',
  full_name='proto.UserRegisterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserRegisterResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.UserRegisterResponse.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.UserRegisterResponse.user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='author_hash', full_name='proto.UserRegisterResponse.author_hash', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='method', full_name='proto.UserRegisterResponse.method', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='resend_delay', full_name='proto.UserRegisterResponse.resend_delay', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sms_number', full_name='proto.UserRegisterResponse.sms_number', index=6,
      number=7, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='verify_code_regex', full_name='proto.UserRegisterResponse.verify_code_regex', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='verify_code_digit_count', full_name='proto.UserRegisterResponse.verify_code_digit_count', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='call_method_supported', full_name='proto.UserRegisterResponse.call_method_supported', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERREGISTERRESPONSE_METHOD,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=724,
)

_USERREGISTER.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERREGISTER.fields_by_name['preference_method'].enum_type = _USERREGISTER_PREFERENCEMETHOD
_USERREGISTER_PREFERENCEMETHOD.containing_type = _USERREGISTER
_USERREGISTERRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERREGISTERRESPONSE.fields_by_name['method'].enum_type = _USERREGISTERRESPONSE_METHOD
_USERREGISTERRESPONSE_METHOD.containing_type = _USERREGISTERRESPONSE
DESCRIPTOR.message_types_by_name['UserRegister'] = _USERREGISTER
DESCRIPTOR.message_types_by_name['UserRegisterResponse'] = _USERREGISTERRESPONSE

UserRegister = _reflection.GeneratedProtocolMessageType('UserRegister', (_message.Message,), dict(
  DESCRIPTOR = _USERREGISTER,
  __module__ = 'UserRegister_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserRegister)
  ))
_sym_db.RegisterMessage(UserRegister)

UserRegisterResponse = _reflection.GeneratedProtocolMessageType('UserRegisterResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERREGISTERRESPONSE,
  __module__ = 'UserRegister_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserRegisterResponse)
  ))
_sym_db.RegisterMessage(UserRegisterResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\021ProtoUserRegister'))
# @@protoc_insertion_point(module_scope)
