# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientResolveUsername.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientResolveUsername.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1b\x43lientResolveUsername.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"J\n\x15\x43lientResolveUsername\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x10\n\x08username\x18\x02 \x01(\t\"\xd7\x01\n\x1d\x43lientResolveUsernameResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).proto.ClientResolveUsernameResponse.Type\x12#\n\x04user\x18\x03 \x01(\x0b\x32\x15.proto.RegisteredUser\x12\x19\n\x04room\x18\x04 \x01(\x0b\x32\x0b.proto.Room\"\x1a\n\x04Type\x12\x08\n\x04USER\x10\x00\x12\x08\n\x04ROOM\x10\x01\x42,\n\x0enet.iGap.protoB\x1aProtoClientResolveUsernameb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTRESOLVEUSERNAMERESPONSE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.ClientResolveUsernameResponse.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROOM', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=349,
  serialized_end=375,
)
_sym_db.RegisterEnumDescriptor(_CLIENTRESOLVEUSERNAMERESPONSE_TYPE)


_CLIENTRESOLVEUSERNAME = _descriptor.Descriptor(
  name='ClientResolveUsername',
  full_name='proto.ClientResolveUsername',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientResolveUsername.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.ClientResolveUsername.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=157,
)


_CLIENTRESOLVEUSERNAMERESPONSE = _descriptor.Descriptor(
  name='ClientResolveUsernameResponse',
  full_name='proto.ClientResolveUsernameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientResolveUsernameResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.ClientResolveUsernameResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user', full_name='proto.ClientResolveUsernameResponse.user', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room', full_name='proto.ClientResolveUsernameResponse.room', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTRESOLVEUSERNAMERESPONSE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=375,
)

_CLIENTRESOLVEUSERNAME.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTRESOLVEUSERNAMERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTRESOLVEUSERNAMERESPONSE.fields_by_name['type'].enum_type = _CLIENTRESOLVEUSERNAMERESPONSE_TYPE
_CLIENTRESOLVEUSERNAMERESPONSE.fields_by_name['user'].message_type = Global__pb2._REGISTEREDUSER
_CLIENTRESOLVEUSERNAMERESPONSE.fields_by_name['room'].message_type = Global__pb2._ROOM
_CLIENTRESOLVEUSERNAMERESPONSE_TYPE.containing_type = _CLIENTRESOLVEUSERNAMERESPONSE
DESCRIPTOR.message_types_by_name['ClientResolveUsername'] = _CLIENTRESOLVEUSERNAME
DESCRIPTOR.message_types_by_name['ClientResolveUsernameResponse'] = _CLIENTRESOLVEUSERNAMERESPONSE

ClientResolveUsername = _reflection.GeneratedProtocolMessageType('ClientResolveUsername', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTRESOLVEUSERNAME,
  __module__ = 'ClientResolveUsername_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientResolveUsername)
  ))
_sym_db.RegisterMessage(ClientResolveUsername)

ClientResolveUsernameResponse = _reflection.GeneratedProtocolMessageType('ClientResolveUsernameResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTRESOLVEUSERNAMERESPONSE,
  __module__ = 'ClientResolveUsername_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientResolveUsernameResponse)
  ))
_sym_db.RegisterMessage(ClientResolveUsernameResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\032ProtoClientResolveUsername'))
# @@protoc_insertion_point(module_scope)
