# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MplGetTopupToken.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='MplGetTopupToken.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16MplGetTopupToken.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xfe\x01\n\x10MplGetTopupToken\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x1c\n\x14\x63harge_mobile_number\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04\x12*\n\x04type\x18\x04 \x01(\x0e\x32\x1c.proto.MplGetTopupToken.Type\"o\n\x04Type\x12\x14\n\x10IRANCELL_PREPAID\x10\x00\x12\x10\n\x0cIRANCELL_WOW\x10\x01\x12\x12\n\x0eIRANCELL_WIMAX\x10\x02\x12\x15\n\x11IRANCELL_POSTPAID\x10\x03\x12\x07\n\x03MCI\x10\x04\x12\x0b\n\x07RIGHTEL\x10\x05\"\x82\x01\n\x18MplGetTopupTokenResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\t\x12\x13\n\x0b\x65xpire_time\x18\x04 \x01(\r\x12\x0f\n\x07message\x18\x05 \x01(\tB\'\n\x0enet.iGap.protoB\x15ProtoMplGetTopupTokenb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_MPLGETTOPUPTOKEN_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.MplGetTopupToken.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_PREPAID', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_WOW', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_WIMAX', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_POSTPAID', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MCI', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RIGHTEL', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=208,
  serialized_end=319,
)
_sym_db.RegisterEnumDescriptor(_MPLGETTOPUPTOKEN_TYPE)


_MPLGETTOPUPTOKEN = _descriptor.Descriptor(
  name='MplGetTopupToken',
  full_name='proto.MplGetTopupToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.MplGetTopupToken.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='charge_mobile_number', full_name='proto.MplGetTopupToken.charge_mobile_number', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.MplGetTopupToken.amount', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.MplGetTopupToken.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MPLGETTOPUPTOKEN_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=319,
)


_MPLGETTOPUPTOKENRESPONSE = _descriptor.Descriptor(
  name='MplGetTopupTokenResponse',
  full_name='proto.MplGetTopupTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.MplGetTopupTokenResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.MplGetTopupTokenResponse.status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.MplGetTopupTokenResponse.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_time', full_name='proto.MplGetTopupTokenResponse.expire_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.MplGetTopupTokenResponse.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=452,
)

_MPLGETTOPUPTOKEN.fields_by_name['request'].message_type = Request__pb2._REQUEST
_MPLGETTOPUPTOKEN.fields_by_name['type'].enum_type = _MPLGETTOPUPTOKEN_TYPE
_MPLGETTOPUPTOKEN_TYPE.containing_type = _MPLGETTOPUPTOKEN
_MPLGETTOPUPTOKENRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['MplGetTopupToken'] = _MPLGETTOPUPTOKEN
DESCRIPTOR.message_types_by_name['MplGetTopupTokenResponse'] = _MPLGETTOPUPTOKENRESPONSE

MplGetTopupToken = _reflection.GeneratedProtocolMessageType('MplGetTopupToken', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETTOPUPTOKEN,
  __module__ = 'MplGetTopupToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetTopupToken)
  ))
_sym_db.RegisterMessage(MplGetTopupToken)

MplGetTopupTokenResponse = _reflection.GeneratedProtocolMessageType('MplGetTopupTokenResponse', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETTOPUPTOKENRESPONSE,
  __module__ = 'MplGetTopupToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetTopupTokenResponse)
  ))
_sym_db.RegisterMessage(MplGetTopupTokenResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoMplGetTopupToken'))
# @@protoc_insertion_point(module_scope)
