# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: BillInquiryMci.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='BillInquiryMci.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x14\x42illInquiryMci.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"H\n\x0e\x42illInquiryMci\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x15\n\rmobile_number\x18\x02 \x01(\x04\"\xaf\x02\n\x16\x42illInquiryMciResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x38\n\x08mid_term\x18\x04 \x01(\x0b\x32&.proto.BillInquiryMciResponse.BillInfo\x12\x39\n\tlast_term\x18\x05 \x01(\x0b\x32&.proto.BillInquiryMciResponse.BillInfo\x1a\\\n\x08\x42illInfo\x12\x0e\n\x06status\x18\x01 \x01(\r\x12\x0f\n\x07\x62ill_id\x18\x02 \x01(\x04\x12\x0e\n\x06pay_id\x18\x03 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x04\x12\x0f\n\x07message\x18\x05 \x01(\tB%\n\x0enet.iGap.protoB\x13ProtoBillInquiryMcib\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_BILLINQUIRYMCI = _descriptor.Descriptor(
  name='BillInquiryMci',
  full_name='proto.BillInquiryMci',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.BillInquiryMci.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mobile_number', full_name='proto.BillInquiryMci.mobile_number', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=134,
)


_BILLINQUIRYMCIRESPONSE_BILLINFO = _descriptor.Descriptor(
  name='BillInfo',
  full_name='proto.BillInquiryMciResponse.BillInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.BillInquiryMciResponse.BillInfo.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bill_id', full_name='proto.BillInquiryMciResponse.BillInfo.bill_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pay_id', full_name='proto.BillInquiryMciResponse.BillInfo.pay_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.BillInquiryMciResponse.BillInfo.amount', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.BillInquiryMciResponse.BillInfo.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=440,
)

_BILLINQUIRYMCIRESPONSE = _descriptor.Descriptor(
  name='BillInquiryMciResponse',
  full_name='proto.BillInquiryMciResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.BillInquiryMciResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.BillInquiryMciResponse.status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.BillInquiryMciResponse.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mid_term', full_name='proto.BillInquiryMciResponse.mid_term', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_term', full_name='proto.BillInquiryMciResponse.last_term', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_BILLINQUIRYMCIRESPONSE_BILLINFO, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=440,
)

_BILLINQUIRYMCI.fields_by_name['request'].message_type = Request__pb2._REQUEST
_BILLINQUIRYMCIRESPONSE_BILLINFO.containing_type = _BILLINQUIRYMCIRESPONSE
_BILLINQUIRYMCIRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_BILLINQUIRYMCIRESPONSE.fields_by_name['mid_term'].message_type = _BILLINQUIRYMCIRESPONSE_BILLINFO
_BILLINQUIRYMCIRESPONSE.fields_by_name['last_term'].message_type = _BILLINQUIRYMCIRESPONSE_BILLINFO
DESCRIPTOR.message_types_by_name['BillInquiryMci'] = _BILLINQUIRYMCI
DESCRIPTOR.message_types_by_name['BillInquiryMciResponse'] = _BILLINQUIRYMCIRESPONSE

BillInquiryMci = _reflection.GeneratedProtocolMessageType('BillInquiryMci', (_message.Message,), dict(
  DESCRIPTOR = _BILLINQUIRYMCI,
  __module__ = 'BillInquiryMci_pb2'
  # @@protoc_insertion_point(class_scope:proto.BillInquiryMci)
  ))
_sym_db.RegisterMessage(BillInquiryMci)

BillInquiryMciResponse = _reflection.GeneratedProtocolMessageType('BillInquiryMciResponse', (_message.Message,), dict(

  BillInfo = _reflection.GeneratedProtocolMessageType('BillInfo', (_message.Message,), dict(
    DESCRIPTOR = _BILLINQUIRYMCIRESPONSE_BILLINFO,
    __module__ = 'BillInquiryMci_pb2'
    # @@protoc_insertion_point(class_scope:proto.BillInquiryMciResponse.BillInfo)
    ))
  ,
  DESCRIPTOR = _BILLINQUIRYMCIRESPONSE,
  __module__ = 'BillInquiryMci_pb2'
  # @@protoc_insertion_point(class_scope:proto.BillInquiryMciResponse)
  ))
_sym_db.RegisterMessage(BillInquiryMciResponse)
_sym_db.RegisterMessage(BillInquiryMciResponse.BillInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\023ProtoBillInquiryMci'))
# @@protoc_insertion_point(module_scope)
