# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SignalingCandidate.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='SignalingCandidate.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18SignalingCandidate.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"t\n\x12SignalingCandidate\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x11\n\tcandidate\x18\x02 \x01(\t\x12\x10\n\x08sdp_m_id\x18\x03 \x01(\t\x12\x18\n\x10sdp_m_line_index\x18\x04 \x01(\r\"\x8d\x01\n\x1aSignalingCandidateResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x16\n\x0epeer_candidate\x18\x02 \x01(\t\x12\x15\n\rpeer_sdp_m_id\x18\x03 \x01(\t\x12\x1d\n\x15peer_sdp_m_line_index\x18\x04 \x01(\rB)\n\x0enet.iGap.protoB\x17ProtoSignalingCandidateb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SIGNALINGCANDIDATE = _descriptor.Descriptor(
  name='SignalingCandidate',
  full_name='proto.SignalingCandidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.SignalingCandidate.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='proto.SignalingCandidate.candidate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sdp_m_id', full_name='proto.SignalingCandidate.sdp_m_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sdp_m_line_index', full_name='proto.SignalingCandidate.sdp_m_line_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=182,
)


_SIGNALINGCANDIDATERESPONSE = _descriptor.Descriptor(
  name='SignalingCandidateResponse',
  full_name='proto.SignalingCandidateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.SignalingCandidateResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peer_candidate', full_name='proto.SignalingCandidateResponse.peer_candidate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peer_sdp_m_id', full_name='proto.SignalingCandidateResponse.peer_sdp_m_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peer_sdp_m_line_index', full_name='proto.SignalingCandidateResponse.peer_sdp_m_line_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=326,
)

_SIGNALINGCANDIDATE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_SIGNALINGCANDIDATERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['SignalingCandidate'] = _SIGNALINGCANDIDATE
DESCRIPTOR.message_types_by_name['SignalingCandidateResponse'] = _SIGNALINGCANDIDATERESPONSE

SignalingCandidate = _reflection.GeneratedProtocolMessageType('SignalingCandidate', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGCANDIDATE,
  __module__ = 'SignalingCandidate_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingCandidate)
  ))
_sym_db.RegisterMessage(SignalingCandidate)

SignalingCandidateResponse = _reflection.GeneratedProtocolMessageType('SignalingCandidateResponse', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGCANDIDATERESPONSE,
  __module__ = 'SignalingCandidate_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingCandidateResponse)
  ))
_sym_db.RegisterMessage(SignalingCandidateResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoSignalingCandidate'))
# @@protoc_insertion_point(module_scope)
