# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PushWalletPaymentVerified.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='PushWalletPaymentVerified.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1fPushWalletPaymentVerified.proto\x12\x05proto\x1a\x0eResponse.proto\"U\n!PushWalletPaymentVerifiedResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05token\x18\x02 \x01(\tB0\n\x0enet.iGap.protoB\x1eProtoPushWalletPaymentVerifiedb\x06proto3')
  ,
  dependencies=[Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_PUSHWALLETPAYMENTVERIFIEDRESPONSE = _descriptor.Descriptor(
  name='PushWalletPaymentVerifiedResponse',
  full_name='proto.PushWalletPaymentVerifiedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.PushWalletPaymentVerifiedResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.PushWalletPaymentVerifiedResponse.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=143,
)

_PUSHWALLETPAYMENTVERIFIEDRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['PushWalletPaymentVerifiedResponse'] = _PUSHWALLETPAYMENTVERIFIEDRESPONSE

PushWalletPaymentVerifiedResponse = _reflection.GeneratedProtocolMessageType('PushWalletPaymentVerifiedResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUSHWALLETPAYMENTVERIFIEDRESPONSE,
  __module__ = 'PushWalletPaymentVerified_pb2'
  # @@protoc_insertion_point(class_scope:proto.PushWalletPaymentVerifiedResponse)
  ))
_sym_db.RegisterMessage(PushWalletPaymentVerifiedResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\036ProtoPushWalletPaymentVerified'))
# @@protoc_insertion_point(module_scope)
