# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InfoConfig.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='InfoConfig.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x10InfoConfig.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"-\n\nInfoConfig\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xb6\x04\n\x12InfoConfigResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x12\n\ndebug_mode\x18\x02 \x01(\x08\x12\x17\n\x0f\x64\x65\x66\x61ult_timeout\x18\x03 \x01(\r\x12\x15\n\roptimize_mode\x18\x04 \x01(\x08\x12\x15\n\rmax_file_size\x18\x05 \x01(\x04\x12\x1a\n\x12\x63\x61ption_length_max\x18\x06 \x01(\x04\x12\x1a\n\x12message_length_max\x18\x07 \x01(\x04\x12\x1e\n\x16group_add_member_limit\x18\x08 \x01(\r\x12 \n\x18\x63hannel_add_member_limit\x18\t \x01(\r\x12*\n\rmicro_service\x18\n \x03(\x0b\x32\x13.proto.MicroService\x12\x34\n\x08\x64\x65\x62ugger\x18\x0b \x01(\x0e\x32\".proto.InfoConfigResponse.Debugger\x12\x10\n\x08\x62\x61se_url\x18\x0c \x01(\t\x12\x18\n\x10show_advertising\x18\r \x01(\x08\x12\x31\n\ndefaultTab\x18\x0e \x01(\x0e\x32\x1d.proto.InfoConfigResponse.Tab\"\'\n\x08\x44\x65\x62ugger\x12\x0f\n\x0b\x43RASHLYTICS\x10\x00\x12\n\n\x06SENTRY\x10\x01\">\n\x03Tab\x12\x0b\n\x07\x43ONTACT\x10\x00\x12\x08\n\x04\x43\x41LL\x10\x01\x12\x08\n\x04\x43HAT\x10\x02\x12\t\n\x05ILAND\x10\x03\x12\x0b\n\x07SETTING\x10\x04\"w\n\x0cMicroService\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\".proto.MicroService.ConnectionType\"\'\n\x0e\x43onnectionType\x12\t\n\x05HTTPS\x10\x00\x12\n\n\x06SOCKET\x10\x01\x42!\n\x0enet.iGap.protoB\x0fProtoInfoConfigb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_INFOCONFIGRESPONSE_DEBUGGER = _descriptor.EnumDescriptor(
  name='Debugger',
  full_name='proto.InfoConfigResponse.Debugger',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CRASHLYTICS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENTRY', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=569,
  serialized_end=608,
)
_sym_db.RegisterEnumDescriptor(_INFOCONFIGRESPONSE_DEBUGGER)

_INFOCONFIGRESPONSE_TAB = _descriptor.EnumDescriptor(
  name='Tab',
  full_name='proto.InfoConfigResponse.Tab',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTACT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALL', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHAT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILAND', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SETTING', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=610,
  serialized_end=672,
)
_sym_db.RegisterEnumDescriptor(_INFOCONFIGRESPONSE_TAB)

_MICROSERVICE_CONNECTIONTYPE = _descriptor.EnumDescriptor(
  name='ConnectionType',
  full_name='proto.MicroService.ConnectionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HTTPS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOCKET', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=754,
  serialized_end=793,
)
_sym_db.RegisterEnumDescriptor(_MICROSERVICE_CONNECTIONTYPE)


_INFOCONFIG = _descriptor.Descriptor(
  name='InfoConfig',
  full_name='proto.InfoConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.InfoConfig.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=103,
)


_INFOCONFIGRESPONSE = _descriptor.Descriptor(
  name='InfoConfigResponse',
  full_name='proto.InfoConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.InfoConfigResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debug_mode', full_name='proto.InfoConfigResponse.debug_mode', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='default_timeout', full_name='proto.InfoConfigResponse.default_timeout', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='optimize_mode', full_name='proto.InfoConfigResponse.optimize_mode', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_file_size', full_name='proto.InfoConfigResponse.max_file_size', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='caption_length_max', full_name='proto.InfoConfigResponse.caption_length_max', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_length_max', full_name='proto.InfoConfigResponse.message_length_max', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_add_member_limit', full_name='proto.InfoConfigResponse.group_add_member_limit', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_add_member_limit', full_name='proto.InfoConfigResponse.channel_add_member_limit', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='micro_service', full_name='proto.InfoConfigResponse.micro_service', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debugger', full_name='proto.InfoConfigResponse.debugger', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_url', full_name='proto.InfoConfigResponse.base_url', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='show_advertising', full_name='proto.InfoConfigResponse.show_advertising', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='defaultTab', full_name='proto.InfoConfigResponse.defaultTab', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INFOCONFIGRESPONSE_DEBUGGER,
    _INFOCONFIGRESPONSE_TAB,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=672,
)


_MICROSERVICE = _descriptor.Descriptor(
  name='MicroService',
  full_name='proto.MicroService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.MicroService.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.MicroService.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MICROSERVICE_CONNECTIONTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=793,
)

_INFOCONFIG.fields_by_name['request'].message_type = Request__pb2._REQUEST
_INFOCONFIGRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_INFOCONFIGRESPONSE.fields_by_name['micro_service'].message_type = _MICROSERVICE
_INFOCONFIGRESPONSE.fields_by_name['debugger'].enum_type = _INFOCONFIGRESPONSE_DEBUGGER
_INFOCONFIGRESPONSE.fields_by_name['defaultTab'].enum_type = _INFOCONFIGRESPONSE_TAB
_INFOCONFIGRESPONSE_DEBUGGER.containing_type = _INFOCONFIGRESPONSE
_INFOCONFIGRESPONSE_TAB.containing_type = _INFOCONFIGRESPONSE
_MICROSERVICE.fields_by_name['type'].enum_type = _MICROSERVICE_CONNECTIONTYPE
_MICROSERVICE_CONNECTIONTYPE.containing_type = _MICROSERVICE
DESCRIPTOR.message_types_by_name['InfoConfig'] = _INFOCONFIG
DESCRIPTOR.message_types_by_name['InfoConfigResponse'] = _INFOCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['MicroService'] = _MICROSERVICE

InfoConfig = _reflection.GeneratedProtocolMessageType('InfoConfig', (_message.Message,), dict(
  DESCRIPTOR = _INFOCONFIG,
  __module__ = 'InfoConfig_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoConfig)
  ))
_sym_db.RegisterMessage(InfoConfig)

InfoConfigResponse = _reflection.GeneratedProtocolMessageType('InfoConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _INFOCONFIGRESPONSE,
  __module__ = 'InfoConfig_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoConfigResponse)
  ))
_sym_db.RegisterMessage(InfoConfigResponse)

MicroService = _reflection.GeneratedProtocolMessageType('MicroService', (_message.Message,), dict(
  DESCRIPTOR = _MICROSERVICE,
  __module__ = 'InfoConfig_pb2'
  # @@protoc_insertion_point(class_scope:proto.MicroService)
  ))
_sym_db.RegisterMessage(MicroService)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\017ProtoInfoConfig'))
# @@protoc_insertion_point(module_scope)
