# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientGetRoomHistory.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientGetRoomHistory.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1a\x43lientGetRoomHistory.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xca\x01\n\x14\x43lientGetRoomHistory\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x18\n\x10\x66irst_message_id\x18\x03 \x01(\x04\x12\x38\n\tdirection\x18\x04 \x01(\x0e\x32%.proto.ClientGetRoomHistory.Direction\x12\r\n\x05limit\x18\x05 \x01(\r\"\x1d\n\tDirection\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\"f\n\x1c\x43lientGetRoomHistoryResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12#\n\x07message\x18\x02 \x03(\x0b\x32\x12.proto.RoomMessageB+\n\x0enet.iGap.protoB\x19ProtoClientGetRoomHistoryb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTGETROOMHISTORY_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='proto.ClientGetRoomHistory.Direction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UP', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=256,
  serialized_end=285,
)
_sym_db.RegisterEnumDescriptor(_CLIENTGETROOMHISTORY_DIRECTION)


_CLIENTGETROOMHISTORY = _descriptor.Descriptor(
  name='ClientGetRoomHistory',
  full_name='proto.ClientGetRoomHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientGetRoomHistory.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ClientGetRoomHistory.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_message_id', full_name='proto.ClientGetRoomHistory.first_message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='direction', full_name='proto.ClientGetRoomHistory.direction', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='limit', full_name='proto.ClientGetRoomHistory.limit', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTGETROOMHISTORY_DIRECTION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=285,
)


_CLIENTGETROOMHISTORYRESPONSE = _descriptor.Descriptor(
  name='ClientGetRoomHistoryResponse',
  full_name='proto.ClientGetRoomHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientGetRoomHistoryResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.ClientGetRoomHistoryResponse.message', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=389,
)

_CLIENTGETROOMHISTORY.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTGETROOMHISTORY.fields_by_name['direction'].enum_type = _CLIENTGETROOMHISTORY_DIRECTION
_CLIENTGETROOMHISTORY_DIRECTION.containing_type = _CLIENTGETROOMHISTORY
_CLIENTGETROOMHISTORYRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTGETROOMHISTORYRESPONSE.fields_by_name['message'].message_type = Global__pb2._ROOMMESSAGE
DESCRIPTOR.message_types_by_name['ClientGetRoomHistory'] = _CLIENTGETROOMHISTORY
DESCRIPTOR.message_types_by_name['ClientGetRoomHistoryResponse'] = _CLIENTGETROOMHISTORYRESPONSE

ClientGetRoomHistory = _reflection.GeneratedProtocolMessageType('ClientGetRoomHistory', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETROOMHISTORY,
  __module__ = 'ClientGetRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetRoomHistory)
  ))
_sym_db.RegisterMessage(ClientGetRoomHistory)

ClientGetRoomHistoryResponse = _reflection.GeneratedProtocolMessageType('ClientGetRoomHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETROOMHISTORYRESPONSE,
  __module__ = 'ClientGetRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetRoomHistoryResponse)
  ))
_sym_db.RegisterMessage(ClientGetRoomHistoryResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\031ProtoClientGetRoomHistory'))
# @@protoc_insertion_point(module_scope)
