# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientRoomReport.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientRoomReport.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16\x43lientRoomReport.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xe6\x01\n\x10\x43lientRoomReport\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x01(\x04\x12.\n\x06reason\x18\x04 \x01(\x0e\x32\x1e.proto.ClientRoomReport.Reason\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"G\n\x06Reason\x12\t\n\x05OTHER\x10\x00\x12\x08\n\x04SPAM\x10\x01\x12\x0f\n\x0bPORNOGRAPHY\x10\x02\x12\x0c\n\x08VIOLENCE\x10\x03\x12\t\n\x05\x41\x42USE\x10\x04\"=\n\x18\x43lientRoomReportResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.ResponseB\'\n\x0enet.iGap.protoB\x15ProtoClientRoomReportb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTROOMREPORT_REASON = _descriptor.EnumDescriptor(
  name='Reason',
  full_name='proto.ClientRoomReport.Reason',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPAM', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PORNOGRAPHY', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIOLENCE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABUSE', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=224,
  serialized_end=295,
)
_sym_db.RegisterEnumDescriptor(_CLIENTROOMREPORT_REASON)


_CLIENTROOMREPORT = _descriptor.Descriptor(
  name='ClientRoomReport',
  full_name='proto.ClientRoomReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientRoomReport.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ClientRoomReport.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ClientRoomReport.message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='proto.ClientRoomReport.reason', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.ClientRoomReport.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTROOMREPORT_REASON,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=295,
)


_CLIENTROOMREPORTRESPONSE = _descriptor.Descriptor(
  name='ClientRoomReportResponse',
  full_name='proto.ClientRoomReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientRoomReportResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=358,
)

_CLIENTROOMREPORT.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTROOMREPORT.fields_by_name['reason'].enum_type = _CLIENTROOMREPORT_REASON
_CLIENTROOMREPORT_REASON.containing_type = _CLIENTROOMREPORT
_CLIENTROOMREPORTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['ClientRoomReport'] = _CLIENTROOMREPORT
DESCRIPTOR.message_types_by_name['ClientRoomReportResponse'] = _CLIENTROOMREPORTRESPONSE

ClientRoomReport = _reflection.GeneratedProtocolMessageType('ClientRoomReport', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTROOMREPORT,
  __module__ = 'ClientRoomReport_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientRoomReport)
  ))
_sym_db.RegisterMessage(ClientRoomReport)

ClientRoomReportResponse = _reflection.GeneratedProtocolMessageType('ClientRoomReportResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTROOMREPORTRESPONSE,
  __module__ = 'ClientRoomReport_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientRoomReportResponse)
  ))
_sym_db.RegisterMessage(ClientRoomReportResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoClientRoomReport'))
# @@protoc_insertion_point(module_scope)
