# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PushLoginToken.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='PushLoginToken.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x14PushLoginToken.proto\x12\x05proto\x1a\x0eResponse.proto\"\x82\x01\n\x16PushLoginTokenResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x12\x13\n\x0b\x61uthor_hash\x18\x04 \x01(\t\x12\r\n\x05token\x18\x05 \x01(\tB%\n\x0enet.iGap.protoB\x13ProtoPushLoginTokenb\x06proto3')
  ,
  dependencies=[Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_PUSHLOGINTOKENRESPONSE = _descriptor.Descriptor(
  name='PushLoginTokenResponse',
  full_name='proto.PushLoginTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.PushLoginTokenResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.PushLoginTokenResponse.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.PushLoginTokenResponse.user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='author_hash', full_name='proto.PushLoginTokenResponse.author_hash', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.PushLoginTokenResponse.token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=178,
)

_PUSHLOGINTOKENRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['PushLoginTokenResponse'] = _PUSHLOGINTOKENRESPONSE

PushLoginTokenResponse = _reflection.GeneratedProtocolMessageType('PushLoginTokenResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUSHLOGINTOKENRESPONSE,
  __module__ = 'PushLoginToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.PushLoginTokenResponse)
  ))
_sym_db.RegisterMessage(PushLoginTokenResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\023ProtoPushLoginToken'))
# @@protoc_insertion_point(module_scope)
