# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientCondition.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientCondition.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x15\x43lientCondition.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xbc\x05\n\x0f\x43lientCondition\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12*\n\x05rooms\x18\x02 \x03(\x0b\x32\x1b.proto.ClientCondition.Room\x1a\xdb\x04\n\x04Room\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x17\n\x0fmessage_version\x18\x03 \x01(\x04\x12\x16\n\x0estatus_version\x18\x04 \x01(\x04\x12\x16\n\x0e\x64\x65lete_version\x18\x05 \x01(\x04\x12\"\n\x1aoffline_deleted_deprecated\x18\x06 \x03(\x04\x12\x41\n\x0eoffline_edited\x18\x07 \x03(\x0b\x32).proto.ClientCondition.Room.OfflineEdited\x12\x14\n\x0coffline_seen\x18\x08 \x03(\x04\x12\x10\n\x08\x63lear_id\x18\t \x01(\x04\x12\x16\n\x0e\x63\x61\x63he_start_id\x18\n \x01(\x04\x12\x14\n\x0c\x63\x61\x63he_end_id\x18\x0b \x01(\x04\x12=\n\x0coffline_mute\x18\x0c \x01(\x0e\x32\'.proto.ClientCondition.Room.OfflineMute\x12\x18\n\x10offline_listened\x18\r \x03(\x04\x12\x43\n\x0foffline_deleted\x18\x0e \x03(\x0b\x32*.proto.ClientCondition.Room.OfflineDeleted\x1a\x34\n\rOfflineEdited\x12\x12\n\nmessage_id\x18\x01 \x01(\x04\x12\x0f\n\x07message\x18\x02 \x01(\t\x1a\x32\n\x0eOfflineDeleted\x12\x12\n\nmessage_id\x18\x01 \x01(\x04\x12\x0c\n\x04\x62oth\x18\x04 \x01(\x08\"4\n\x0bOfflineMute\x12\r\n\tUNCHANGED\x10\x00\x12\t\n\x05MUTED\x10\x01\x12\x0b\n\x07UNMUTED\x10\x02\"<\n\x17\x43lientConditionResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.ResponseB&\n\x0enet.iGap.protoB\x14ProtoClientConditionb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTCONDITION_ROOM_OFFLINEMUTE = _descriptor.EnumDescriptor(
  name='OfflineMute',
  full_name='proto.ClientCondition.Room.OfflineMute',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNCHANGED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MUTED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNMUTED', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=712,
  serialized_end=764,
)
_sym_db.RegisterEnumDescriptor(_CLIENTCONDITION_ROOM_OFFLINEMUTE)


_CLIENTCONDITION_ROOM_OFFLINEEDITED = _descriptor.Descriptor(
  name='OfflineEdited',
  full_name='proto.ClientCondition.Room.OfflineEdited',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ClientCondition.Room.OfflineEdited.message_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.ClientCondition.Room.OfflineEdited.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=606,
  serialized_end=658,
)

_CLIENTCONDITION_ROOM_OFFLINEDELETED = _descriptor.Descriptor(
  name='OfflineDeleted',
  full_name='proto.ClientCondition.Room.OfflineDeleted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ClientCondition.Room.OfflineDeleted.message_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='both', full_name='proto.ClientCondition.Room.OfflineDeleted.both', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=710,
)

_CLIENTCONDITION_ROOM = _descriptor.Descriptor(
  name='Room',
  full_name='proto.ClientCondition.Room',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ClientCondition.Room.room_id', index=0,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_version', full_name='proto.ClientCondition.Room.message_version', index=1,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_version', full_name='proto.ClientCondition.Room.status_version', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delete_version', full_name='proto.ClientCondition.Room.delete_version', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_deleted_deprecated', full_name='proto.ClientCondition.Room.offline_deleted_deprecated', index=4,
      number=6, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_edited', full_name='proto.ClientCondition.Room.offline_edited', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_seen', full_name='proto.ClientCondition.Room.offline_seen', index=6,
      number=8, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clear_id', full_name='proto.ClientCondition.Room.clear_id', index=7,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cache_start_id', full_name='proto.ClientCondition.Room.cache_start_id', index=8,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cache_end_id', full_name='proto.ClientCondition.Room.cache_end_id', index=9,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_mute', full_name='proto.ClientCondition.Room.offline_mute', index=10,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_listened', full_name='proto.ClientCondition.Room.offline_listened', index=11,
      number=13, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_deleted', full_name='proto.ClientCondition.Room.offline_deleted', index=12,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTCONDITION_ROOM_OFFLINEEDITED, _CLIENTCONDITION_ROOM_OFFLINEDELETED, ],
  enum_types=[
    _CLIENTCONDITION_ROOM_OFFLINEMUTE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=764,
)

_CLIENTCONDITION = _descriptor.Descriptor(
  name='ClientCondition',
  full_name='proto.ClientCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientCondition.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rooms', full_name='proto.ClientCondition.rooms', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTCONDITION_ROOM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=764,
)


_CLIENTCONDITIONRESPONSE = _descriptor.Descriptor(
  name='ClientConditionResponse',
  full_name='proto.ClientConditionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientConditionResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=826,
)

_CLIENTCONDITION_ROOM_OFFLINEEDITED.containing_type = _CLIENTCONDITION_ROOM
_CLIENTCONDITION_ROOM_OFFLINEDELETED.containing_type = _CLIENTCONDITION_ROOM
_CLIENTCONDITION_ROOM.fields_by_name['offline_edited'].message_type = _CLIENTCONDITION_ROOM_OFFLINEEDITED
_CLIENTCONDITION_ROOM.fields_by_name['offline_mute'].enum_type = _CLIENTCONDITION_ROOM_OFFLINEMUTE
_CLIENTCONDITION_ROOM.fields_by_name['offline_deleted'].message_type = _CLIENTCONDITION_ROOM_OFFLINEDELETED
_CLIENTCONDITION_ROOM.containing_type = _CLIENTCONDITION
_CLIENTCONDITION_ROOM_OFFLINEMUTE.containing_type = _CLIENTCONDITION_ROOM
_CLIENTCONDITION.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTCONDITION.fields_by_name['rooms'].message_type = _CLIENTCONDITION_ROOM
_CLIENTCONDITIONRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['ClientCondition'] = _CLIENTCONDITION
DESCRIPTOR.message_types_by_name['ClientConditionResponse'] = _CLIENTCONDITIONRESPONSE

ClientCondition = _reflection.GeneratedProtocolMessageType('ClientCondition', (_message.Message,), dict(

  Room = _reflection.GeneratedProtocolMessageType('Room', (_message.Message,), dict(

    OfflineEdited = _reflection.GeneratedProtocolMessageType('OfflineEdited', (_message.Message,), dict(
      DESCRIPTOR = _CLIENTCONDITION_ROOM_OFFLINEEDITED,
      __module__ = 'ClientCondition_pb2'
      # @@protoc_insertion_point(class_scope:proto.ClientCondition.Room.OfflineEdited)
      ))
    ,

    OfflineDeleted = _reflection.GeneratedProtocolMessageType('OfflineDeleted', (_message.Message,), dict(
      DESCRIPTOR = _CLIENTCONDITION_ROOM_OFFLINEDELETED,
      __module__ = 'ClientCondition_pb2'
      # @@protoc_insertion_point(class_scope:proto.ClientCondition.Room.OfflineDeleted)
      ))
    ,
    DESCRIPTOR = _CLIENTCONDITION_ROOM,
    __module__ = 'ClientCondition_pb2'
    # @@protoc_insertion_point(class_scope:proto.ClientCondition.Room)
    ))
  ,
  DESCRIPTOR = _CLIENTCONDITION,
  __module__ = 'ClientCondition_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientCondition)
  ))
_sym_db.RegisterMessage(ClientCondition)
_sym_db.RegisterMessage(ClientCondition.Room)
_sym_db.RegisterMessage(ClientCondition.Room.OfflineEdited)
_sym_db.RegisterMessage(ClientCondition.Room.OfflineDeleted)

ClientConditionResponse = _reflection.GeneratedProtocolMessageType('ClientConditionResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTCONDITIONRESPONSE,
  __module__ = 'ClientCondition_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientConditionResponse)
  ))
_sym_db.RegisterMessage(ClientConditionResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\024ProtoClientCondition'))
# @@protoc_insertion_point(module_scope)
