# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientSearchRoomHistory.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientSearchRoomHistory.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1d\x43lientSearchRoomHistory.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xff\x01\n\x17\x43lientSearchRoomHistory\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0e\n\x06offset\x18\x03 \x01(\r\x12\x35\n\x06\x66ilter\x18\x04 \x01(\x0e\x32%.proto.ClientSearchRoomHistory.Filter\x12\x19\n\x11offset_message_id\x18\x05 \x01(\x04\"P\n\x06\x46ilter\x12\t\n\x05IMAGE\x10\x00\x12\t\n\x05VIDEO\x10\x01\x12\t\n\x05\x41UDIO\x10\x02\x12\t\n\x05VOICE\x10\x03\x12\x07\n\x03GIF\x10\x04\x12\x08\n\x04\x46ILE\x10\x05\x12\x07\n\x03URL\x10\x06\"\x95\x01\n\x1f\x43lientSearchRoomHistoryResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x12\n\ntotalCount\x18\x02 \x01(\r\x12\x17\n\x0fnotDeletedCount\x18\x03 \x01(\r\x12\"\n\x06result\x18\x04 \x03(\x0b\x32\x12.proto.RoomMessageB.\n\x0enet.iGap.protoB\x1cProtoClientSearchRoomHistoryb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTSEARCHROOMHISTORY_FILTER = _descriptor.EnumDescriptor(
  name='Filter',
  full_name='proto.ClientSearchRoomHistory.Filter',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMAGE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUDIO', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VOICE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GIF', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=261,
  serialized_end=341,
)
_sym_db.RegisterEnumDescriptor(_CLIENTSEARCHROOMHISTORY_FILTER)


_CLIENTSEARCHROOMHISTORY = _descriptor.Descriptor(
  name='ClientSearchRoomHistory',
  full_name='proto.ClientSearchRoomHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientSearchRoomHistory.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ClientSearchRoomHistory.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='proto.ClientSearchRoomHistory.offset', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='proto.ClientSearchRoomHistory.filter', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset_message_id', full_name='proto.ClientSearchRoomHistory.offset_message_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTSEARCHROOMHISTORY_FILTER,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=341,
)


_CLIENTSEARCHROOMHISTORYRESPONSE = _descriptor.Descriptor(
  name='ClientSearchRoomHistoryResponse',
  full_name='proto.ClientSearchRoomHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientSearchRoomHistoryResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='totalCount', full_name='proto.ClientSearchRoomHistoryResponse.totalCount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='notDeletedCount', full_name='proto.ClientSearchRoomHistoryResponse.notDeletedCount', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='proto.ClientSearchRoomHistoryResponse.result', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=493,
)

_CLIENTSEARCHROOMHISTORY.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTSEARCHROOMHISTORY.fields_by_name['filter'].enum_type = _CLIENTSEARCHROOMHISTORY_FILTER
_CLIENTSEARCHROOMHISTORY_FILTER.containing_type = _CLIENTSEARCHROOMHISTORY
_CLIENTSEARCHROOMHISTORYRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTSEARCHROOMHISTORYRESPONSE.fields_by_name['result'].message_type = Global__pb2._ROOMMESSAGE
DESCRIPTOR.message_types_by_name['ClientSearchRoomHistory'] = _CLIENTSEARCHROOMHISTORY
DESCRIPTOR.message_types_by_name['ClientSearchRoomHistoryResponse'] = _CLIENTSEARCHROOMHISTORYRESPONSE

ClientSearchRoomHistory = _reflection.GeneratedProtocolMessageType('ClientSearchRoomHistory', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTSEARCHROOMHISTORY,
  __module__ = 'ClientSearchRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientSearchRoomHistory)
  ))
_sym_db.RegisterMessage(ClientSearchRoomHistory)

ClientSearchRoomHistoryResponse = _reflection.GeneratedProtocolMessageType('ClientSearchRoomHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTSEARCHROOMHISTORYRESPONSE,
  __module__ = 'ClientSearchRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientSearchRoomHistoryResponse)
  ))
_sym_db.RegisterMessage(ClientSearchRoomHistoryResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\034ProtoClientSearchRoomHistory'))
# @@protoc_insertion_point(module_scope)
