# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ConnectionSecuring.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ConnectionSecuring.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18\x43onnectionSecuring.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xc6\x01\n\x1a\x43onnectionSecuringResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x12\n\npublic_key\x18\x02 \x01(\t\x12\x1c\n\x14symmetric_key_length\x18\x03 \x01(\r\x12\x1a\n\x12heartbeat_interval\x18\x04 \x01(\r\x12\x19\n\x11primary_node_name\x18\x05 \x01(\t\x12\x1c\n\x14secondary_chunk_size\x18\x06 \x01(\r\"a\n\x16\x43onnectionSymmetricKey\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x15\n\rsymmetric_key\x18\x02 \x01(\x0c\x12\x0f\n\x07version\x18\x03 \x01(\r\"\xf4\x01\n\x1e\x43onnectionSymmetricKeyResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12<\n\x06status\x18\x02 \x01(\x0e\x32,.proto.ConnectionSymmetricKeyResponse.Status\x12\x18\n\x10symmetric_method\x18\x03 \x01(\t\x12\x19\n\x11symmetric_iv_size\x18\x04 \x01(\r\x12\x16\n\x0esecurity_issue\x18\x05 \x01(\x08\"$\n\x06Status\x12\x0c\n\x08REJECTED\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x42)\n\x0enet.iGap.protoB\x17ProtoConnectionSecuringb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CONNECTIONSYMMETRICKEYRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='proto.ConnectionSymmetricKeyResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=575,
  serialized_end=611,
)
_sym_db.RegisterEnumDescriptor(_CONNECTIONSYMMETRICKEYRESPONSE_STATUS)


_CONNECTIONSECURINGRESPONSE = _descriptor.Descriptor(
  name='ConnectionSecuringResponse',
  full_name='proto.ConnectionSecuringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ConnectionSecuringResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='proto.ConnectionSecuringResponse.public_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symmetric_key_length', full_name='proto.ConnectionSecuringResponse.symmetric_key_length', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heartbeat_interval', full_name='proto.ConnectionSecuringResponse.heartbeat_interval', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='primary_node_name', full_name='proto.ConnectionSecuringResponse.primary_node_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='secondary_chunk_size', full_name='proto.ConnectionSecuringResponse.secondary_chunk_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=265,
)


_CONNECTIONSYMMETRICKEY = _descriptor.Descriptor(
  name='ConnectionSymmetricKey',
  full_name='proto.ConnectionSymmetricKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ConnectionSymmetricKey.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symmetric_key', full_name='proto.ConnectionSymmetricKey.symmetric_key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='proto.ConnectionSymmetricKey.version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=364,
)


_CONNECTIONSYMMETRICKEYRESPONSE = _descriptor.Descriptor(
  name='ConnectionSymmetricKeyResponse',
  full_name='proto.ConnectionSymmetricKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ConnectionSymmetricKeyResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.ConnectionSymmetricKeyResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symmetric_method', full_name='proto.ConnectionSymmetricKeyResponse.symmetric_method', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symmetric_iv_size', full_name='proto.ConnectionSymmetricKeyResponse.symmetric_iv_size', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='security_issue', full_name='proto.ConnectionSymmetricKeyResponse.security_issue', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTIONSYMMETRICKEYRESPONSE_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=611,
)

_CONNECTIONSECURINGRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CONNECTIONSYMMETRICKEY.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CONNECTIONSYMMETRICKEYRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CONNECTIONSYMMETRICKEYRESPONSE.fields_by_name['status'].enum_type = _CONNECTIONSYMMETRICKEYRESPONSE_STATUS
_CONNECTIONSYMMETRICKEYRESPONSE_STATUS.containing_type = _CONNECTIONSYMMETRICKEYRESPONSE
DESCRIPTOR.message_types_by_name['ConnectionSecuringResponse'] = _CONNECTIONSECURINGRESPONSE
DESCRIPTOR.message_types_by_name['ConnectionSymmetricKey'] = _CONNECTIONSYMMETRICKEY
DESCRIPTOR.message_types_by_name['ConnectionSymmetricKeyResponse'] = _CONNECTIONSYMMETRICKEYRESPONSE

ConnectionSecuringResponse = _reflection.GeneratedProtocolMessageType('ConnectionSecuringResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONSECURINGRESPONSE,
  __module__ = 'ConnectionSecuring_pb2'
  # @@protoc_insertion_point(class_scope:proto.ConnectionSecuringResponse)
  ))
_sym_db.RegisterMessage(ConnectionSecuringResponse)

ConnectionSymmetricKey = _reflection.GeneratedProtocolMessageType('ConnectionSymmetricKey', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONSYMMETRICKEY,
  __module__ = 'ConnectionSecuring_pb2'
  # @@protoc_insertion_point(class_scope:proto.ConnectionSymmetricKey)
  ))
_sym_db.RegisterMessage(ConnectionSymmetricKey)

ConnectionSymmetricKeyResponse = _reflection.GeneratedProtocolMessageType('ConnectionSymmetricKeyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONSYMMETRICKEYRESPONSE,
  __module__ = 'ConnectionSecuring_pb2'
  # @@protoc_insertion_point(class_scope:proto.ConnectionSymmetricKeyResponse)
  ))
_sym_db.RegisterMessage(ConnectionSymmetricKeyResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoConnectionSecuring'))
# @@protoc_insertion_point(module_scope)
