# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GeoGetRegisterStatus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GeoGetRegisterStatus.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1aGeoGetRegisterStatus.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"7\n\x14GeoGetRegisterStatus\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"Q\n\x1cGeoGetRegisterStatusResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x42+\n\x0enet.iGap.protoB\x19ProtoGeoGetRegisterStatusb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GEOGETREGISTERSTATUS = _descriptor.Descriptor(
  name='GeoGetRegisterStatus',
  full_name='proto.GeoGetRegisterStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GeoGetRegisterStatus.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=123,
)


_GEOGETREGISTERSTATUSRESPONSE = _descriptor.Descriptor(
  name='GeoGetRegisterStatusResponse',
  full_name='proto.GeoGetRegisterStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GeoGetRegisterStatusResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enable', full_name='proto.GeoGetRegisterStatusResponse.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=206,
)

_GEOGETREGISTERSTATUS.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GEOGETREGISTERSTATUSRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['GeoGetRegisterStatus'] = _GEOGETREGISTERSTATUS
DESCRIPTOR.message_types_by_name['GeoGetRegisterStatusResponse'] = _GEOGETREGISTERSTATUSRESPONSE

GeoGetRegisterStatus = _reflection.GeneratedProtocolMessageType('GeoGetRegisterStatus', (_message.Message,), dict(
  DESCRIPTOR = _GEOGETREGISTERSTATUS,
  __module__ = 'GeoGetRegisterStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetRegisterStatus)
  ))
_sym_db.RegisterMessage(GeoGetRegisterStatus)

GeoGetRegisterStatusResponse = _reflection.GeneratedProtocolMessageType('GeoGetRegisterStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _GEOGETREGISTERSTATUSRESPONSE,
  __module__ = 'GeoGetRegisterStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetRegisterStatusResponse)
  ))
_sym_db.RegisterMessage(GeoGetRegisterStatusResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\031ProtoGeoGetRegisterStatus'))
# @@protoc_insertion_point(module_scope)
