# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientRegisterDevice.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientRegisterDevice.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1a\x43lientRegisterDevice.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xaa\x01\n\x14\x43lientRegisterDevice\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\r\n\x05token\x18\x02 \x01(\t\x12.\n\x04type\x18\x03 \x01(\x0e\x32 .proto.ClientRegisterDevice.Type\"2\n\x04Type\x12\x0b\n\x07GENERIC\x10\x00\x12\x0b\n\x07\x41NDROID\x10\x01\x12\x07\n\x03IOS\x10\x02\x12\x07\n\x03WEB\x10\x03\"A\n\x1c\x43lientRegisterDeviceResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.ResponseB+\n\x0enet.iGap.protoB\x19ProtoClientRegisterDeviceb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTREGISTERDEVICE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.ClientRegisterDevice.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GENERIC', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANDROID', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEB', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=189,
  serialized_end=239,
)
_sym_db.RegisterEnumDescriptor(_CLIENTREGISTERDEVICE_TYPE)


_CLIENTREGISTERDEVICE = _descriptor.Descriptor(
  name='ClientRegisterDevice',
  full_name='proto.ClientRegisterDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientRegisterDevice.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.ClientRegisterDevice.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.ClientRegisterDevice.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTREGISTERDEVICE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=239,
)


_CLIENTREGISTERDEVICERESPONSE = _descriptor.Descriptor(
  name='ClientRegisterDeviceResponse',
  full_name='proto.ClientRegisterDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientRegisterDeviceResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=306,
)

_CLIENTREGISTERDEVICE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTREGISTERDEVICE.fields_by_name['type'].enum_type = _CLIENTREGISTERDEVICE_TYPE
_CLIENTREGISTERDEVICE_TYPE.containing_type = _CLIENTREGISTERDEVICE
_CLIENTREGISTERDEVICERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['ClientRegisterDevice'] = _CLIENTREGISTERDEVICE
DESCRIPTOR.message_types_by_name['ClientRegisterDeviceResponse'] = _CLIENTREGISTERDEVICERESPONSE

ClientRegisterDevice = _reflection.GeneratedProtocolMessageType('ClientRegisterDevice', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTREGISTERDEVICE,
  __module__ = 'ClientRegisterDevice_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientRegisterDevice)
  ))
_sym_db.RegisterMessage(ClientRegisterDevice)

ClientRegisterDeviceResponse = _reflection.GeneratedProtocolMessageType('ClientRegisterDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTREGISTERDEVICERESPONSE,
  __module__ = 'ClientRegisterDevice_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientRegisterDeviceResponse)
  ))
_sym_db.RegisterMessage(ClientRegisterDeviceResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\031ProtoClientRegisterDevice'))
# @@protoc_insertion_point(module_scope)
