# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupChangeMemberRights.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GroupChangeMemberRights.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1dGroupChangeMemberRights.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xcd\x02\n\x17GroupChangeMemberRights\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x12?\n\npermission\x18\x04 \x01(\x0b\x32+.proto.GroupChangeMemberRights.MemberRights\x1a\xad\x01\n\x0cMemberRights\x12\x11\n\tsend_text\x18\x01 \x01(\x08\x12\x12\n\nsend_media\x18\x03 \x01(\x08\x12\x10\n\x08send_gif\x18\x04 \x01(\x08\x12\x14\n\x0csend_sticker\x18\x05 \x01(\x08\x12\x11\n\tsend_link\x18\x06 \x01(\x08\x12\x13\n\x0bpin_message\x18\x07 \x01(\x08\x12\x12\n\nadd_member\x18\x08 \x01(\x08\x12\x12\n\nget_member\x18\t \x01(\x08\"\xa7\x01\n\x1fGroupChangeMemberRightsResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x12?\n\npermission\x18\x04 \x01(\x0b\x32+.proto.GroupChangeMemberRights.MemberRightsB.\n\x0enet.iGap.protoB\x1cProtoGroupChangeMemberRightsb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS = _descriptor.Descriptor(
  name='MemberRights',
  full_name='proto.GroupChangeMemberRights.MemberRights',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='send_text', full_name='proto.GroupChangeMemberRights.MemberRights.send_text', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_media', full_name='proto.GroupChangeMemberRights.MemberRights.send_media', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_gif', full_name='proto.GroupChangeMemberRights.MemberRights.send_gif', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_sticker', full_name='proto.GroupChangeMemberRights.MemberRights.send_sticker', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_link', full_name='proto.GroupChangeMemberRights.MemberRights.send_link', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin_message', full_name='proto.GroupChangeMemberRights.MemberRights.pin_message', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='add_member', full_name='proto.GroupChangeMemberRights.MemberRights.add_member', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='get_member', full_name='proto.GroupChangeMemberRights.MemberRights.get_member', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=405,
)

_GROUPCHANGEMEMBERRIGHTS = _descriptor.Descriptor(
  name='GroupChangeMemberRights',
  full_name='proto.GroupChangeMemberRights',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GroupChangeMemberRights.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupChangeMemberRights.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.GroupChangeMemberRights.user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='proto.GroupChangeMemberRights.permission', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=405,
)


_GROUPCHANGEMEMBERRIGHTSRESPONSE = _descriptor.Descriptor(
  name='GroupChangeMemberRightsResponse',
  full_name='proto.GroupChangeMemberRightsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GroupChangeMemberRightsResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupChangeMemberRightsResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.GroupChangeMemberRightsResponse.user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='proto.GroupChangeMemberRightsResponse.permission', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=408,
  serialized_end=575,
)

_GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS.containing_type = _GROUPCHANGEMEMBERRIGHTS
_GROUPCHANGEMEMBERRIGHTS.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GROUPCHANGEMEMBERRIGHTS.fields_by_name['permission'].message_type = _GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS
_GROUPCHANGEMEMBERRIGHTSRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GROUPCHANGEMEMBERRIGHTSRESPONSE.fields_by_name['permission'].message_type = _GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS
DESCRIPTOR.message_types_by_name['GroupChangeMemberRights'] = _GROUPCHANGEMEMBERRIGHTS
DESCRIPTOR.message_types_by_name['GroupChangeMemberRightsResponse'] = _GROUPCHANGEMEMBERRIGHTSRESPONSE

GroupChangeMemberRights = _reflection.GeneratedProtocolMessageType('GroupChangeMemberRights', (_message.Message,), dict(

  MemberRights = _reflection.GeneratedProtocolMessageType('MemberRights', (_message.Message,), dict(
    DESCRIPTOR = _GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS,
    __module__ = 'GroupChangeMemberRights_pb2'
    # @@protoc_insertion_point(class_scope:proto.GroupChangeMemberRights.MemberRights)
    ))
  ,
  DESCRIPTOR = _GROUPCHANGEMEMBERRIGHTS,
  __module__ = 'GroupChangeMemberRights_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupChangeMemberRights)
  ))
_sym_db.RegisterMessage(GroupChangeMemberRights)
_sym_db.RegisterMessage(GroupChangeMemberRights.MemberRights)

GroupChangeMemberRightsResponse = _reflection.GeneratedProtocolMessageType('GroupChangeMemberRightsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GROUPCHANGEMEMBERRIGHTSRESPONSE,
  __module__ = 'GroupChangeMemberRights_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupChangeMemberRightsResponse)
  ))
_sym_db.RegisterMessage(GroupChangeMemberRightsResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\034ProtoGroupChangeMemberRights'))
# @@protoc_insertion_point(module_scope)
