# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientGetDiscovery.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientGetDiscovery.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18\x43lientGetDiscovery.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"k\n\x12\x43lientGetDiscovery\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07page_id\x18\x02 \x01(\r\x12\x12\n\nproject_id\x18\x03 \x01(\r\x12\x0f\n\x07item_id\x18\x04 \x01(\r\"u\n\x1a\x43lientGetDiscoveryResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05title\x18\x02 \x01(\t\x12%\n\x0b\x64iscoveries\x18\x03 \x03(\x0b\x32\x10.proto.DiscoveryB)\n\x0enet.iGap.protoB\x17ProtoClientGetDiscoveryb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CLIENTGETDISCOVERY = _descriptor.Descriptor(
  name='ClientGetDiscovery',
  full_name='proto.ClientGetDiscovery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientGetDiscovery.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='page_id', full_name='proto.ClientGetDiscovery.page_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='proto.ClientGetDiscovery.project_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='proto.ClientGetDiscovery.item_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=187,
)


_CLIENTGETDISCOVERYRESPONSE = _descriptor.Descriptor(
  name='ClientGetDiscoveryResponse',
  full_name='proto.ClientGetDiscoveryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientGetDiscoveryResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='proto.ClientGetDiscoveryResponse.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='discoveries', full_name='proto.ClientGetDiscoveryResponse.discoveries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=306,
)

_CLIENTGETDISCOVERY.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTGETDISCOVERYRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTGETDISCOVERYRESPONSE.fields_by_name['discoveries'].message_type = Global__pb2._DISCOVERY
DESCRIPTOR.message_types_by_name['ClientGetDiscovery'] = _CLIENTGETDISCOVERY
DESCRIPTOR.message_types_by_name['ClientGetDiscoveryResponse'] = _CLIENTGETDISCOVERYRESPONSE

ClientGetDiscovery = _reflection.GeneratedProtocolMessageType('ClientGetDiscovery', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETDISCOVERY,
  __module__ = 'ClientGetDiscovery_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetDiscovery)
  ))
_sym_db.RegisterMessage(ClientGetDiscovery)

ClientGetDiscoveryResponse = _reflection.GeneratedProtocolMessageType('ClientGetDiscoveryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETDISCOVERYRESPONSE,
  __module__ = 'ClientGetDiscovery_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetDiscoveryResponse)
  ))
_sym_db.RegisterMessage(ClientGetDiscoveryResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoClientGetDiscovery'))
# @@protoc_insertion_point(module_scope)
